@@ -1,8 +1,10 @@
 from accim.sim import accis
 accis.addAccis(
     ScriptType='ex_mm',
-    Outputs='standard',
-    EnergyPlus_version='ep95',
+    Output_keep_existing=False,
+    Output_type='standard',
+    Output_freqs=['hourly'],
+    EnergyPlus_version='9.5',
     TempCtrl='temp',
     ComfStand=[1],
     CAT=[1, 2, 3],
